@@ -2,8 +2,7 @@ from contextlib import suppress
 
 
 class TagMixin:
-    """Adds tagging support to a domain model.
-    """
+    """Adds tagging support to a domain model."""
 
     def add_tags(self, tags):
         self.tags = list(set(self.tags).union(set(tags)))
